@@ -278,8 +278,6 @@ class Specs(SpecSet):
     ksmstate = RegistryPoint()
     kubepods_cpu_quota = RegistryPoint(multi_output=True)
     lastupload = RegistryPoint(multi_output=True)
-    libkeyutils_objdumps = RegistryPoint()
-    libkeyutils = RegistryPoint()
     libssh_client_config = RegistryPoint(filterable=True)
     libssh_server_config = RegistryPoint(filterable=True)
     libvirtd_log = RegistryPoint(filterable=True)
@@ -352,6 +350,7 @@ class Specs(SpecSet):
     modinfo = RegistryPoint(multi_output=True)
     modinfo_all = RegistryPoint()
     modprobe = RegistryPoint(multi_output=True)
+    mokutil_sbstate = RegistryPoint()
     mongod_conf = RegistryPoint(multi_output=True, filterable=True)
     mount = RegistryPoint()
     mounts = RegistryPoint()
@@ -430,6 +429,7 @@ class Specs(SpecSet):
     octavia_conf = RegistryPoint(filterable=True)
     odbc_ini = RegistryPoint(filterable=True)
     odbcinst_ini = RegistryPoint()
+    open_vm_tools_stat_raw_text_session = RegistryPoint()
     openvswitch_other_config = RegistryPoint()
     openvswitch_server_log = RegistryPoint(filterable=True)
     openshift_certificates = RegistryPoint(multi_output=True)
@@ -668,7 +668,6 @@ class Specs(SpecSet):
     vmware_tools_conf = RegistryPoint()
     vsftpd_conf = RegistryPoint(filterable=True)
     vsftpd = RegistryPoint()
-    woopsie = RegistryPoint()
     x86_pti_enabled = RegistryPoint()
     x86_ibpb_enabled = RegistryPoint()
     x86_ibrs_enabled = RegistryPoint()
